Сертификати | OiRA
Description: В зависимост от подхода, възприет от националния партньор на OiRA / разработчик на инструменти, може да е предвидена възможността да получите сертификат за извършената от вас оценка на риска. Информация за предимствата, които обезпечава наличието на такъв сертификат, можете да получите от националния партньор на OiRA във вашата страна.

Теми

# Сертификати

В зависимост от подхода, възприет от националния партньор на OiRA / разработчик на инструменти, може да е предвидена възможността да получите сертификат за извършената от вас оценка на риска. Информация за предимствата, които обезпечава наличието на такъв сертификат, можете да получите от националния партньор на OiRA във вашата страна.

Как да получите сертификат

## Извършете пълна оценка на риска

Докато изпълнявате етапите на оценката на риска, OiRA ще документира вашия напредък. След като оцените определен брой рискове, инструментът ще ви уведоми за възможността да получите сертификат, след като извършите пълна оценка на риска. Всеки национален партньор на OiRA / разработчик на инструменти определя прагово ниво (изразено в проценти), което трябва да е налице, за да се счита оценката за „пълна“. Можете да получите сертификата, като щракнете върху бутона „Статус“ в менюто в лявата част на екрана.

Страницата „Статус“ показва, че е налице сертификат.

## Прегледайте и публикувайте вашия сертификат

Когато щракнете върху бутона „Преглед на сертификат“, ще получите указания да въведете наименованието на дружеството, което трябва да фигурира в сертификата. В зависимост от най-добрите практики за съответната страна е възможно да получите указания да въведете допълнителни данни, с цел сертификатът да съдържа цялата информация, която трябва да предоставите.

Въведете цялата информация, която е необходима за издаване на сертификата.

Ако отбележите квадратчето „Публичен достъп“, ще се появи уникален адрес (URL) на вашия сертификат. Копирайте го и го споделете със съответните лица като доказателство, че сте извършили оценка на риска.

Бележка: Единствено данните, показани на тази страница, ще станат публични. Този адрес не е наличен в менюто на уебсайта на OiRA –- той е достъпен само за вас. Въпреки това теоретично всеки, който използва интернет, може да види създадения от вас сертификат!

Сертификатът показва единствено, че сте въвели информация за определен брой рискове в инструмента за оценка на риска, и не съдържа никаква друга информация. Конкретните отговори, които сте въвели в процеса на изготвяне на оценка на риска с помощта на инструмента за OiRA, са достъпни само за вас и за никого другиго.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More